<html>

<head>
  <meta charset="utf-8" />
  <title>Sample Auth0 Login Page</title>
</head>

<body>
  <!-- define an area that is centered and at most 500px wide -->
  <div
    style="max-width: 500px; margin-left: auto; margin-right: auto; min-height: 100%; background-color: lightgrey; border-radius: 30px;">
    <div style="padding-left: 20px; padding-right: 20px; padding-top: 5px; padding-bottom: 20px;">
      {% block body %}
      <h1>Auth0 Login</h1>
      {% if user.is_authenticated %}
      <p>
      Welcome, {{ user.first_name }}.
      We're not sure which page you were supposed to go to, so you ended up here.
      Enjoy!
      </p>
      <p><a href="{% url 'auth0_logout' %}">Logout</a></p>
      {% else %}
      <button><a href="{% url 'auth0_login' %}">Go to Login</a></button>
      {% endif %}
      {% endblock %}
    </div>
  </div>
</body>
</html>
